tiled.client.xarray.DatasetClient
=================================

.. currentmodule:: tiled.client.xarray

.. autoclass:: DatasetClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DatasetClient.__init__
      ~DatasetClient.discover_clients_from_entrypoints
      ~DatasetClient.distinct
      ~DatasetClient.download
      ~DatasetClient.export
      ~DatasetClient.get
      ~DatasetClient.items
      ~DatasetClient.keys
      ~DatasetClient.login
      ~DatasetClient.logout
      ~DatasetClient.new
      ~DatasetClient.new_variation
      ~DatasetClient.read
      ~DatasetClient.refresh
      ~DatasetClient.search
      ~DatasetClient.sort
      ~DatasetClient.update_metadata
      ~DatasetClient.values
      ~DatasetClient.write_array
      ~DatasetClient.write_dataframe
      ~DatasetClient.write_sparse
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DatasetClient.STRUCTURE_CLIENTS_FROM_ENTRYPOINTS
      ~DatasetClient.context
      ~DatasetClient.formats
      ~DatasetClient.item
      ~DatasetClient.items_indexer
      ~DatasetClient.keys_indexer
      ~DatasetClient.metadata
      ~DatasetClient.metadata_revisions
      ~DatasetClient.offline
      ~DatasetClient.references
      ~DatasetClient.sorting
      ~DatasetClient.specs
      ~DatasetClient.uri
      ~DatasetClient.values_indexer
   
   